@@ -806,7 +806,7 @@ gedit_plugins_engine_configure_plugin (GeditPluginsEngine *engine,
 	gtk_window_set_transient_for (GTK_WINDOW (conf_dlg),
 				      parent);
 
-	wg = parent->group;		      
+	wg = gtk_window_get_group (parent);
 	if (wg == NULL)
 	{
 		wg = gtk_window_group_new ();
