@@ -531,7 +531,12 @@ get_from_bookmark_file (GeditFileBrowserWidget * obj, GFile * file,
 	item = (NameIcon *)data;
 
 	*name = g_strdup (item->name);
-	*icon = g_object_ref (item->icon);
+	*icon = item->icon;
+
+	if (item->icon != NULL)
+	{
+		g_object_ref (item->icon);
+	}
 
 	return TRUE;
 }
@@ -787,7 +792,7 @@ static GtkActionEntry toplevel_actions[] =
 
 static const GtkActionEntry tree_actions_selection[] = 
 {
-	{"FileMoveToTrash", "gnome-stock-trash", N_("_Move To Trash"), NULL,
+	{"FileMoveToTrash", "gnome-stock-trash", N_("_Move to Trash"), NULL,
 	 N_("Move selected file or folder to trash"),
 	 G_CALLBACK (on_action_file_move_to_trash)},
 	{"FileDelete", GTK_STOCK_DELETE, N_("_Delete"), NULL,
